#
# spec file for package python-snuggs
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         skip_python36 1
Name:           python-snuggs
Version:        1.4.7
Release:        4.7
Summary:        S-expressions tool for Numpy
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/mapbox/snuggs
Source:         https://files.pythonhosted.org/packages/source/s/snuggs/snuggs-%{version}.tar.gz
# PATCH-FIX-UPSTREAM 28-non-strict-xfail.patch gh#mapbox/snuggs#27 mcepl@suse.com
# synchronize skipping of failing tests with Debian
Patch0:         28-non-strict-xfail.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Requires:       python-pyparsing
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pyparsing}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Snuggs are s-expressions for Numpy.

%prep
%autosetup -p1 -n snuggs-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest test_snuggs.py

%files %{python_files}
%doc AUTHORS.txt CHANGES.txt README.rst
%license LICENSE
%{python_sitelib}/snuggs
%{python_sitelib}/snuggs-%{version}*-info

%changelog
* Sat Nov 25 2023 Matej Cepl <mcepl@cepl.eu>
- Add 28-non-strict-xfail.patch synchronizing skipping of failing
  tests with Debian.
* Sat Sep  9 2023 Matej Cepl <mcepl@suse.com>
- Skip failing tests because of poor exception handling
  (gh#mapbox/snuggs#27)
* Tue Apr 27 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Thu Sep 19 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to 1.4.7
  The snuggs tests of syntax errors no longer assert a specific pyparsing
  exception message as the format of these messages is not stable (#15).
  Previous versions of snuggs had no other issues with pyparsing 2.3 or 2.4.
  + 1.4.6 (2019-05-15)
  * Tests were failing on Python 2.7 (#20, #21) due to loss of precision in
    str(num). This has been fixed by using repr(num).
  + 1.4.5 (2019-05-14)
    + Replace custom integer and real parsers with pyparsing_common's number (#19).
  + 1.4.4 (2019-05-14)
    + Fix for a reported bug in parsing negative real numbers (#16) and for an
    unreported bug in parsing numbers in exponential notation (thank you,
    hypothesis!).
    + Add a "test" dependency on hypothesis.
- Packaging
  + Add hypothesis buildrequire
  + spec-cleaner minimal
  + Fix build errors on TW
* Wed Mar  6 2019 Todd R <toddrme2178@gmail.com>
- Update to 1.4.3
  * Add LICENSE to distributions (#11).
  * Remove click from requirements (#12).
  * Allow a wider range of valid variable and parameter names (#13).
- Update to 1.4.2
  * Add missing docstrings and improve existing ones.
- Update to 1.4.1
  * Bug fix: accept OrderedDict as evaluation context to enable reliable read()
    indexing (#9, #10).
- Update to 1.4.0
  * New feature: mathematical operators like + and * can take multiple arguments
    as in Hy and other Lisps (#7).
- Implement singlespec version
* Tue Jun  9 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- initial packaging (1.3.1)
